# Installation
> `npm install --save @types/katex`

# Summary
This package contains type definitions for KaTeX (http://khan.github.io/KaTeX/).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/katex

Additional Details
 * Last updated: Wed, 11 Sep 2019 05:55:46 GMT
 * Dependencies: none
 * Global values: katex

# Credits
These definitions were written by Michael Randolph <https://github.com/mrand01>, Kevin Nguyen <https://github.com/knguyen0125>, bLue <https://github.com/dreamerblue>, and Sebastian Weigand <https://github.com/s-weigand>.
